Module offchain

Module offchain 

Functions

add_extra_account_metas_for_freeze
add_extra_account_metas_for_thaw

Type Aliases

AccountDataResult
Type representing the output of an account fetching function, for easy chaining between APIs
AccountFetchError
Generic error type that can come out of any client while fetching account data